[−][src]Crate tab_websocket
Modules
| bus | |
| message | |
| resource | |
| service |
Functions
| bind | Binds to the TCP stream as a server, requring the auth token, and capturing request metadata via a lifeline request. |
| connect | Connects to the provided URL, with no authentication token |
| connect_authorized | Connects to the provided URL, given an authentication token |
| decode | Decodes the bincode-serialized message |
| encode | Encodes the message into a bincode-serialized tungstenite message |
Type Definitions
| WebsocketConnection |